Welcome to CGDAT’s documentation! — CGDAT 2.0.0-2-g2917492 documentation

# Welcome to CGDAT’s documentation!

This tool was created to aid in a more streamlined game data analysis. The repository of this tool can be found on github.

## Contents:

- Installation
  - Install the package using the installer script
  - Build and install the package yourself
  - Create a windows shortcut
- How to use this tool
  - Use as a GUI
  - Use as a package
- Contributors

## For Developers:

- API Reference

## Indices and tables

- Index
- Module Index
- Search Page